# This file is part of fedmsg.
# Copyright (C) 2018 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Pierre-Yves Chibon <pingou@pingoured.fr>
#
""" Tests for pagure messages """

import unittest

from fedmsg_meta_fedora_infrastructure.tests.base import Base

from .common import add_doc


class TestSimpleKojiCiPR(Base):
    """ These messages are published when someone asks for a re-run of
    simple-koji-ci on a pull-request on `dist-git
    <https://src.fedoraproject.org/>`_.
    """
    expected_title = "rats.test.simple-koji-ci"
    expected_subti = 'pingou requested a run of simple-koji-ci on ' + \
        '"rpms/python-arrow/pull-request/13"'
    expected_link = "https://src.fedoraproject.org/rpms/python-arrow/pull-request/13"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['simple-koji-ci/rpms/python-arrow/pull-request/13'])
    msg = {
      "i": 1,
      "timestamp": 1515756462,
      "msg_id": "2018-40a4a95d-9274-4972-be1b-db43a1959012",
      "topic": "org.fedoraproject.dev.rats.test.simple-koji-ci",
      "msg": {
        "agent": "pingou",
        "extras": {},
        "pull_request": {
          "status": "Open",
          "last_updated": "1506692613",
          "branch_from": "master",
          "uid": "11700bb635a94953b449c8de14d2d16d",
          "title": "Test PR",
          "initial_comment": None,
          "comments": [],
          "id": 13,
          "project": {
            "custom_keys": [],
            "description": "The python-arrow rpms",
            "parent": None,
            "date_modified": "1507625578",
            "access_users": {
              "admin": [
                "pingou"
              ],
              "commit": [],
              "ticket": [],
              "owner": [
                "ralph"
              ]
            },
            "namespace": "rpms",
            "priorities": {},
            "id": 16710,
            "access_groups": {
              "admin": [],
              "commit": [
                "infra-sig"
              ],
              "ticket": []
            },
            "milestones": {},
            "user": {
              "fullname": "Ralph Bean",
              "name": "ralph"
            },
            "date_created": "1501276912",
            "fullname": "rpms/python-arrow",
            "url_path": "rpms/python-arrow",
            "close_status": [],
            "tags": [],
            "name": "python-arrow"
          },
          "commit_stop": "f71b3aa0f313d34eabb8b182619314de37c67c90",
          "repo_from": None,
          "updated_on": "1506619100",
          "assignee": None,
          "commit_start": "b9750aae92def8c714a3378c8086d0f3c90ffcc0",
          "branch": "master",
          "date_created": "1506619100",
          "remote_git": None,
          "closed_at": None,
          "closed_by": None,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "name": "pingou"
          }
        },
        "test": "simple-koji-ci",
        "identifier": "rpms/python-arrow/pull-request/13",
        "result_id": None
      }
    }


class TestTaskotronBuild(Base):
    """ These messages are published when someone asks for a re-run of
    a specific test on taskotron for a specific build.
    """
    expected_title = "rats.test.taskotron"
    expected_subti = 'pingou requested a run of taskotron\'s ' + \
        'dist.rpmdeplint on "audit-2.8-1.fc26"'
    expected_link = None
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['taskotron/dist.rpmdeplint/audit-2.8-1.fc26'])
    msg = {
      "i": 1,
      "timestamp": 1515768967,
      "msg_id": "2018-96b2b575-0b83-412d-b931-6cf73b653011",
      "topic": "org.fedoraproject.dev.rats.test.taskotron",
      "msg": {
        "agent": "pingou",
        "extras": {
          "groups": "foobar"
        },
        "groups": "foobar",
        "test": "dist.rpmdeplint",
        "identifier": "audit-2.8-1.fc26",
        "result_id": None
      }
    }


class TestTaskotronResultId(Base):
    """ These messages are published when someone asks for a re-run of
    a specific test on taskotron from a resultsdb's result identifier.
    """
    expected_title = "rats.test.taskotron"
    expected_subti = 'pingou requested a run of taskotron on ' + \
        'resultsdb\'s result id: "17783947"'
    expected_link = None
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['taskotron/resultsdb/17783947'])
    msg = {
      "i": 1,
      "timestamp": 1515770465,
      "msg_id": "2018-aacc5b52-a3a2-4b34-a111-3a4cde2eead4",
      "topic": "org.fedoraproject.dev.rats.test.taskotron",
      "msg": {
        "agent": "pingou",
        "extras": {},
        "groups": [
          "7275e744-90a2-58ee-9973-b0d6fa7c0267",
          "cf4f1f88-e873-5432-86a4-15a12e400f87",
          "0f3309ea-6d4c-59b2-b422-d73e9b8511f3"
        ],
        "test": None,
        "identifier": None,
        "result_id": "17783947"
      }
    }


class TestAtomicCIPR(Base):
    """ These messages are published when someone asks for a re-run of
    the Atomic CI pipeline from a pull-request.
    """
    expected_title = "rats.test.atomic-ci"
    expected_subti = 'pingou requested a run of atomic-ci on ' + \
        '"rpms/python-arrow/pull-request/13"'
    expected_link = None
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['AtomicCI/rpms/python-arrow/pull-request/13'])
    msg = {
      "i": 4,
      "timestamp": 1516010094,
      "msg_id": "2018-a7b54439-4bb8-48e5-87b7-975fea6efd15",
      "topic": "org.fedoraproject.dev.rats.test.atomic-ci",
      "msg": {
        "old_result": None,
        "agent": "pingou",
        "extras": {},
        "pull_request": {
          "status": "Open",
          "last_updated": "1506692613",
          "branch_from": "master",
          "uid": "11700bb635a94953b449c8de14d2d16d",
          "title": "Test PR",
          "initial_comment": None,
          "comments": [
            {
              "comment": "test comment\r\n\r\nEdited2",
              "parent": None,
              "notification": False,
              "tree": None,
              "filename": None,
              "edited_on": "1506692613",
              "editor": {
                "fullname": "Pierre-YvesChibon",
                "name": "pingou"
              },
              "date_created": "1506689892",
              "commit": None,
              "line": None,
              "id": 27,
              "user": {
                "fullname": "Pierre-YvesChibon",
                "name": "pingou"
              }
            }
          ],
          "id": 13,
          "project": {
            "custom_keys": [],
            "description": "The python-arrow rpms",
            "parent": None,
            "date_modified": "1507625578",
            "access_users": {
              "admin": [
                "pingou"
              ],
              "commit": [],
              "ticket": [],
              "owner": [
                "ralph"
              ]
            },
            "namespace": "rpms",
            "priorities": {},
            "id": 16710,
            "access_groups": {
              "admin": [],
              "commit": [
                "infra-sig"
              ],
              "ticket": []
            },
            "milestones": {},
            "user": {
              "fullname": "Ralph Bean",
              "name": "ralph"
            },
            "date_created": "1501276912",
            "fullname": "rpms/python-arrow",
            "url_path": "rpms/python-arrow",
            "close_status": [],
            "tags": [],
            "name": "python-arrow"
          },
          "commit_stop": "f71b3aa0f313d34eabb8b182619314de37c67c90",
          "repo_from": None,
          "updated_on": "1506619100",
          "assignee": None,
          "commit_start": "b9750aae92def8c714a3378c8086d0f3c90ffcc0",
          "branch": "master",
          "date_created": "1506619100",
          "remote_git": None,
          "closed_at": None,
          "closed_by": None,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "name": "pingou"
          }
        },
        "test": "AtomicCI",
        "identifier": "rpms/python-arrow/pull-request/13",
        "result_id": None
      }
    }


class TestAtomicCIResultId(Base):
    """ These messages are published when someone asks for a re-run of
    the Atomic CI pipeline from a resultsdb's result identifier.
    """
    expected_title = "rats.test.atomic-ci"
    expected_subti = 'pingou requested a run of atomic-ci on ' + \
        'resultsdb\'s result id: "17786885"'
    expected_link = None
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['AtomicCI/resultsdb/17786885'])
    msg = {
      "i": 5,
      "timestamp": 1516009806,
      "msg_id": "2018-390b5760-0bfa-4f08-bd98-513c24d2ed7b",
      "topic": "org.fedoraproject.dev.rats.test.atomic-ci",
      "msg": {
        "old_result": {
          "testcase": {
            "ref_url": None,
            "href": "https://taskotron.fedoraproject.org/resultsdb_api/api/v2.0/testcases/org.centos.prod.ci.pipeline.complete",
            "name": "org.centos.prod.ci.pipeline.complete"
          },
          "ref_url": "https://jenkins-continuous-infra.apps.ci.centos.org/job/continuous-infra-ci-pipeline-f27/46/",
          "note": None,
          "href": "https://taskotron.fedoraproject.org/resultsdb_api/api/v2.0/results/17786885",
          "groups": [],
          "submit_time": "2017-10-23T18:12:12.381783",
          "outcome": "PASSED",
          "data": {
            "build_id": [
              "46"
            ],
            "status": [
              "SUCCESS"
            ],
            "msg_id": [
              "2017-2acbcd52-fd49-4d34-8411-70476139cdd8"
            ],
            "group": [
              "None"
            ],
            "nvr": [
              "glusterfs-3.12.2-2.408.202c34e.fc27.x86_64"
            ],
            "ref": [
              "x86_64"
            ],
            "rev": [
              "202c34e6826fd2cba34ee61fc14312126ede808f"
            ],
            "username": [
              "fedora-atomic"
            ],
            "build_url": [
              "https://jenkins-continuous-infra.apps.ci.centos.org/job/continuous-infra-ci-pipeline-f27/46/"
            ],
            "namespace": [
              "rpms"
            ],
            "repo": [
              "glusterfs"
            ],
            "topic": [
              "org.centos.prod.ci.pipeline.complete"
            ],
            "original_spec_nvr": [
              "glusterfs-3.12.2-2.fc27"
            ],
            "centos_ci_resultsdb": [
              "True"
            ],
            "branch": [
              "f27"
            ],
            "centos_ci_resultsdb_id": [
              "32627"
            ],
            "centos_ci_resultsdb_submit_time": [
              "2017-10-23T18:11:13.949695"
            ]
          },
          "id": 17786885
        },
        "agent": "pingou",
        "extras": {},
        "pull_request": None,
        "test": None,
        "identifier": None,
        "result_id": "17786885"
      }
    }

add_doc(locals())

if __name__ == '__main__':
    unittest.main()



# This file is part of fedmsg.
# Copyright (C) 2017 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Pierre-Yves Chibon <pingou@pingoured.fr>
#
""" Tests for ci.centos.org messages """

import unittest

from fedmsg.tests.test_meta import Base

from .common import add_doc


class TestPackageIgnore(Base):
    """ These messages are published when the Atomic CI pipeline announces that
    it ignores a commit made on dist-git.
    """

    expected_title = "ci.pipeline.package.ignore"
    expected_subti = 'Commit "ada94828" of package rpms/protobuf is being '\
        'ignored by the Atomic CI pipeline on branch f26'
    expected_link = "https://ci.centos.org/job/ci-pipeline-2-0/47/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/protobuf/ada94828daa8fcd0bb68ce13e3ad123545d1c7cc/'
         'f26/package/ignore'])
    msg = {
      "i": 1,
      "timestamp": 1498625602.0,
      "msg_id": "2017-e3ce244c-a1ea-496f-9a6f-2245dd5ea110",
      "topic": "org.centos.prod.ci.pipeline.package.ignore",
      "source_version": "0.7.0",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "47",
        "username": "fedora-atomic",
        "rev": "ada94828daa8fcd0bb68ce13e3ad123545d1c7cc",
        "message-content": "",
        "build_url": "https://ci.centos.org/job/ci-pipeline-2-0/47/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-2-0",
        "repo": "protobuf",
        "topic": "org.centos.prod.ci.pipeline.package.ignore",
        "status": "success",
        "branch": "f26",
        "test_guidance": "''",
        "ref": "fedora/f26/x86_64/atomic-host"
      }
    }


class TestPackageComplete(Base):
    """ These messages are published when the Atomic CI pipeline announces that
    the build of a package completed.
    """

    expected_title = "ci.pipeline.package.complete"
    expected_subti = 'Commit 0cc505ca of package rpms/NetworkManager '\
        'passed building in the Atomic CI pipeline on branch f26'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/8/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/NetworkManager/0cc505ca294de0daa6260bd80e65e18a318b8057/'
         'f26/package/complete'])
    msg = {
      "i": 1,
      "timestamp": 1500665940.0,
      "msg_id": "2017-3a8e6539-d16d-49da-8a33-ac4c3f75dd27",
      "topic": "org.centos.prod.ci.pipeline.package.complete",
      "source_version": "0.7.0",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "8",
        "username": "fedora-atomic",
        "rev": "0cc505ca294de0daa6260bd80e65e18a318b8057",
        "message-content": "",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/8/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-f26",
        "repo": "NetworkManager",
        "topic": "org.centos.stage.ci.pipeline.package.complete",
        "status": "SUCCESS",
        "test_guidance": "''",
        "branch": "f26",
        "package_url": "http://artifacts.ci.centos.org/fedora-atomic/f26/repo/NetworkManager_repo/NetworkManager-1.8.2-2.fc26.673.0cc505c.x86_64.rpm",
        "ref": "fedora/f26/x86_64/atomic-host"
      }
    }


class TestPackageQueued(Base):
    """ These messages are published when the Atomic CI pipeline announces that
    the build of a package is queued.
    """

    expected_title = "ci.pipeline.package.queued"
    expected_subti = 'Commit 0cc505ca of package rpms/NetworkManager is '\
        'queued to be built in the Atomic CI pipeline on branch f26'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-trigger/39/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/NetworkManager/0cc505ca294de0daa6260bd80e65e18a318b8057/'
         'f26/package/queued'])
    msg = {
      "i": 1,
      "timestamp": 1500651841.0,
      "msg_id": "2017-4864d380-a500-4f71-a40e-fe59cc150824",
      "topic": "org.centos.prod.ci.pipeline.package.queued",
      "source_version": "0.7.0",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "39",
        "username": "fedora-atomic",
        "rev": "0cc505ca294de0daa6260bd80e65e18a318b8057",
        "message-content": "",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-trigger/39/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-trigger",
        "repo": "NetworkManager",
        "topic": "org.centos.stage.ci.pipeline.package.queued",
        "status": "success",
        "branch": "f26",
        "test_guidance": "''",
        "ref": "fedora/f26/x86_64/atomic-host"
      }
    }


class TestPackageRunning(Base):
    """ These messages are published when the Atomic CI pipeline announces that
    the build of a package is running.
    """

    expected_title = "ci.pipeline.package.running"
    expected_subti = 'Commit 0cc505ca of package rpms/NetworkManager is '\
        'being built in the Atomic CI pipeline on branch f26'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/5/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/NetworkManager/0cc505ca294de0daa6260bd80e65e18a318b8057/'
         'f26/package/running'])
    msg = {
      "i": 1,
      "timestamp": 1500651862.0,
      "msg_id": "2017-66ce76b7-0519-4807-a9b0-831c61b1da6c",
      "topic": "org.centos.stage.ci.pipeline.package.running",
      "source_version": "0.7.0",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "5",
        "username": "fedora-atomic",
        "rev": "0cc505ca294de0daa6260bd80e65e18a318b8057",
        "message-content": "",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/5/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-f26",
        "repo": "NetworkManager",
        "topic": "org.centos.stage.ci.pipeline.package.running",
        "status": "SUCCESS",
        "branch": "f26",
        "test_guidance": "''",
        "ref": "fedora/f26/x86_64/atomic-host"
      }
    }


class TestComposeComplete(Base):
    """ These messages are published when the Atomic CI pipeline announces that
    a compose containing a specified package has completed.
    """

    expected_title = "ci.pipeline.compose.complete"
    expected_subti = 'Commit 7327f260 of package rpms/device-mapper-multipath ' \
        'passed a compose in the Atomic CI pipeline on branch master'
    expected_link = "https://ci.centos.org/job/ci-pipeline-ostree-compose/772/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/device-mapper-multipath/'
         '7327f260a8a90058efd576b8ce12d78e403d269d/'
         'master/compose/complete'])
    msg = {
      "i": 1,
      "timestamp": 1498242025.0,
      "msg_id": "2017-f3a0d6ca-d0d1-4d2c-a578-040cbfc9e2b0",
      "topic": "org.centos.prod.ci.pipeline.compose.complete",
      "source_version": "0.7.0",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "772",
        "status": "SUCCESS",
        "username": "fedora-atomic",
        "compose_url": "http://artifacts.ci.centos.org/artifacts/fedora-atomic/master/ostree",
        "rev": "7327f260a8a90058efd576b8ce12d78e403d269d",
        "message-content": "",
        "build_url": "https://ci.centos.org/job/ci-pipeline-ostree-compose/772/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-ostree-compose",
        "repo": "device-mapper-multipath",
        "compose_rev": "7a8b6262efe6a4a5194bf48eb4577527fd05c23ff4f2192c276dc98deaa8e718",
        "topic": "org.centos.prod.ci.pipeline.compose.complete",
        "CI_STATUS": "passed",
        "branch": "master",
        "test_guidance": "",
        "ref": "fedora/master/x86_64/atomic-host"
      }
    }


class TestComposeRunning(Base):
    """ These messages are published when the Atomic CI pipeline announces that
    a compose containing a specified package is running.
    """

    expected_title = "ci.pipeline.compose.running"
    expected_subti = 'Commit 7327f260 of package rpms/device-mapper-multipath '\
        'is being part of a compose in the Atomic CI pipeline on branch master'
    expected_link = "https://ci.centos.org/job/ci-pipeline-ostree-compose/772/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/device-mapper-multipath/'
         '7327f260a8a90058efd576b8ce12d78e403d269d/'
         'master/compose/running'])
    msg = {
      "i": 1,
      "timestamp": 1498241532.0,
      "msg_id": "2017-0b1258d6-dfe6-434c-8754-4af0b83ede64",
      "topic": "org.centos.prod.ci.pipeline.compose.running",
      "source_version": "0.7.0",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "772",
        "username": "fedora-atomic",
        "compose_url": "http://artifacts.ci.centos.org/artifacts/fedora-atomic/rawhide/ostree",
        "rev": "7327f260a8a90058efd576b8ce12d78e403d269d",
        "message-content": "",
        "build_url": "https://ci.centos.org/job/ci-pipeline-ostree-compose/772/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-ostree-compose",
        "repo": "device-mapper-multipath",
        "compose_rev": "",
        "topic": "org.centos.prod.ci.pipeline.compose.running",
        "status": "success",
        "branch": "master",
        "test_guidance": "",
        "ref": "fedora/rawhide/x86_64/atomic-host"
      }
    }


class TestComposeTestIntegrationComplete(Base):
    """ These messages are published when the Atomic CI pipeline announces that
    the integration test of a compose containing a specified package has
    completed.
    """

    expected_title = "ci.pipeline.compose.test.integration.complete"
    expected_subti = 'Commit 7b272f5f of package rpms/kernel failed its ' \
        'tests as part of a compose in the Atomic CI pipeline on branch f26'
    expected_link = "https://ci.centos.org/job/ci-pipeline-atomic-host-tests/377/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/' \
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa' \
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/kernel/'
         '7b272f5f610d89eb9077640c3fc13b6472e4c31d/'
         'f26/compose/test/integration/complete'])
    msg = {
      "i": 1,
      "timestamp": 1498577008.0,
      "msg_id": "2017-2f33b69b-6336-4e67-98fa-fc17d0a004bc",
      "topic": "org.centos.prod.ci.pipeline.compose.test.integration.complete",
      "source_version": "0.7.0",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "377",
        "username": "fedora-atomic",
        "compose_url": "http://artifacts.ci.centos.org/artifacts/fedora-atomic/f26/ostree",
        "rev": "7b272f5f610d89eb9077640c3fc13b6472e4c31d",
        "message-content": "",
        "build_url": "https://ci.centos.org/job/ci-pipeline-atomic-host-tests/377/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-atomic-host-tests",
        "repo": "kernel",
        "status": "FAILED",
        "topic": "org.centos.prod.ci.pipeline.compose.test.integration.complete",
        "CI_STATUS": "failed",
        "branch": "f26",
        "test_guidance": "",
        "ref": "fedora/f26/x86_64/atomic-host"
      }
    }


class TestComposeTestIntegrationRunning(Base):
    """ These messages are published when the Atomic CI pipeline announces that
    the integration test of a compose containing a specified package are
    running.
    """

    expected_title = "ci.pipeline.compose.test.integration.running"
    expected_subti = 'Commit 7b272f5f of package rpms/kernel is being '\
        'tested as part of a compose in the Atomic CI pipeline on branch f26'
    expected_link = "https://ci.centos.org/job/ci-pipeline-atomic-host-tests/377/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/kernel/'
         '7b272f5f610d89eb9077640c3fc13b6472e4c31d/'
         'f26/compose/test/integration/running'])
    msg = {
      "i": 1,
      "timestamp": 1498575078.0,
      "msg_id": "2017-cb05d8b5-24d5-4ac0-9424-a21af20ae15c",
      "topic": "org.centos.prod.ci.pipeline.compose.test.integration.running",
      "source_version": "0.7.0",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "377",
        "username": "fedora-atomic",
        "compose_url": "http://artifacts.ci.centos.org/artifacts/fedora-atomic/f26/ostree",
        "rev": "7b272f5f610d89eb9077640c3fc13b6472e4c31d",
        "message-content": "",
        "build_url": "https://ci.centos.org/job/ci-pipeline-atomic-host-tests/377/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-atomic-host-tests",
        "repo": "kernel",
        "topic": "org.centos.prod.ci.pipeline.compose.test.integration.running",
        "status": "success",
        "branch": "f26",
        "test_guidance": "",
        "ref": "fedora/f26/x86_64/atomic-host"
      }
    }


class TestComposeTestIntegrationQueued(Base):
    """ These messages are published when the Atomic CI pipeline announces that
    the integration test of a compose containing a specified package are
    queued.
    """

    expected_title = "ci.pipeline.compose.test.integration.queued"
    expected_subti = 'Commit 77d0810c of package rpms/grub2 is queued for ' \
        'tests as part of a compose in the Atomic CI pipeline on branch f26'
    expected_link = "https://ci.centos.org/job/ci-pipeline-ostree-boot-sanity/537/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/grub2/'
         '77d0810cf0c2dae524736a0c39decffb95c20f4c/'
         'f26/compose/test/integration/queued'])
    msg = {
      "i": 1,
      "timestamp": 1498512283.0,
      "msg_id": "2017-b8b527ce-c03a-48fa-9ff2-d2ee2be9de6d",
      "topic": "org.centos.prod.ci.pipeline.compose.test.integration.queued",
      "source_version": "0.7.0",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "537",
        "username": "fedora-atomic",
        "compose_url": "http://artifacts.ci.centos.org/artifacts/fedora-atomic/f26/ostree",
        "rev": "77d0810cf0c2dae524736a0c39decffb95c20f4c",
        "message-content": "",
        "build_url": "https://ci.centos.org/job/ci-pipeline-ostree-boot-sanity/537/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-ostree-boot-sanity",
        "repo": "grub2",
        "topic": "org.centos.prod.ci.pipeline.compose.test.integration.queued",
        "status": "success",
        "branch": "f26",
        "test_guidance": "",
        "ref": "fedora/f26/x86_64/atomic-host"
      }
    }


class TestImageComplete(Base):
    """ These messages are published when the Atomic CI pipeline announces that
    the build of the image generated from the compose containing a specified
    package has completed.
    """

    expected_title = "ci.pipeline.image.complete"
    expected_subti = 'Commit 77d0810c of package rpms/grub2 failed ' \
        'being built in an image in the Atomic CI pipeline on branch f25'
    expected_link = "https://ci.centos.org/job/ci-pipeline-ostree-image-compose/123/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/' \
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa' \
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/grub2/'
         '77d0810cf0c2dae524736a0c39decffb95c20f4c/'
         'f25/image/complete'])
    msg = {
      "i": 1,
      "timestamp": 1498220998.0,
      "msg_id": "2017-49a59f79-24fb-487a-ba13-bb0901acdab5",
      "topic": "org.centos.prod.ci.pipeline.image.complete",
      "source_version": "0.7.0",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "123",
        "status": "FAILED",
        "username": "fedora-atomic",
        "compose_url": "http://artifacts.ci.centos.org/artifacts/fedora-atomic/f25/ostree",
        "rev": "77d0810cf0c2dae524736a0c39decffb95c20f4c",
        "message-content": "",
        "build_url": "https://ci.centos.org/job/ci-pipeline-ostree-image-compose/123/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-ostree-image-compose",
        "image_name": "fedora-atomic-25.71-ce1d81054a2b79a.qcow2",
        "repo": "grub2",
        "compose_rev": "ce1d81054a2b79a99d66ea413fac25ce94734daa4fec387c39ee03d8e0506158",
        "topic": "org.centos.prod.ci.pipeline.image.complete",
        "CI_STATUS": "passed",
        "test_guidance": "",
        "branch": "f25",
        "type": "qcow2",
        "image_url": "http://artifacts.ci.centos.org/artifacts/fedora-atomic/f25/images/fedora-atomic-25.71-ce1d81054a2b79a.qcow2",
        "ref": "fedora/f25/x86_64/atomic-host"
      }
    }


class TestImageRunning(Base):
    """ These messages are published when the Atomic CI pipeline announces that
    the build of the image generated from the compose containing a specified
    package is running.
    """

    expected_title = "ci.pipeline.image.running"
    expected_subti = 'Commit 0cc505ca of package rpms/NetworkManager is ' \
        'being built in an image in the Atomic CI pipeline on branch f26'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/11/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/NetworkManager/'
         '0cc505ca294de0daa6260bd80e65e18a318b8057/'
         'f26/image/running'])
    msg = {
      "i": 1,
      "timestamp": 1500918319.0,
      "msg_id": "2017-b61a647a-8f98-4f2b-afe9-aa5a7f2ea257",
      "topic": "org.centos.stage.ci.pipeline.image.running",
      "source_version": "0.7.0",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "11",
        "status": "SUCCESS",
        "username": "fedora-atomic",
        "compose_url": "http://artifacts.ci.centos.org/artifacts/fedora-atomic/f26/ostree",
        "rev": "0cc505ca294de0daa6260bd80e65e18a318b8057",
        "message-content": "",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/11/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-f26",
        "image_name": "''",
        "repo": "NetworkManager",
        "compose_rev": "c6ab48d6bb155131de5f16350903c80494e6eecac52a00d369b8b920ccd6dafd",
        "topic": "org.centos.stage.ci.pipeline.image.running",
        "image_url": "''",
        "branch": "f26",
        "type": "qcow2",
        "test_guidance": "''",
        "ref": "fedora/f26/x86_64/atomic-host"
      }
    }


class TestImageTestSmokeComplete(Base):
    """ These messages are published when the Atomic CI pipeline announces that
    the image generated from the compose containing a specified
    package has completed its tests.
    """

    expected_title = "ci.pipeline.image.test.smoke.complete"
    expected_subti = 'Commit fff28640 of package rpms/nspr passed its '\
        'tests in an image in the Atomic CI pipeline on branch f26'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/132/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/nspr/'
         'fff28640d156c8b5e7302b7736e16442087b6007/'
         'f26/image/test/smoke/complete'])
    msg = {
      "i": 1,
      "timestamp": 1500918319.0,
      "msg_id": "2017-b61a647a-8f98-4f2b-afe9-aa5a7f2ea257",
      "topic": "org.centos.prod.ci.pipeline.image.test.smoke.complete",
      "source_version": "0.7.0",
      "msg": {
        "CI_NAME": "ci-pipeline-f26",
        "CI_TYPE": "custom",
        "branch": "f26",
        "build_id": "132",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/132/",
        "compose_rev ": "b1777ffee14021a94d0b027fbcd841a15bd7cdeebd97527b742eab4e666dc9ec",
        "compose_url ": "http: //artifacts.ci.centos.org/artifacts/fedora-atomic/f26/ostree",
        "image_name": "fedora-atomic-26.223-b1777ffee14021a.qcow2",
        "image_url ": "http: //artifacts.ci.centos.org/artifacts/fedora-atomic/f26/images/fedora-atomic-26.223-b1777ffee14021a.qcow2 ",
        "message-content ": "",
        "namespace": "rpms",
        "ref ": "fedora/f26/x86_64/atomic-host",
        "repo": "nspr",
        "rev": "fff28640d156c8b5e7302b7736e16442087b6007",
        "status": "SUCCESS",
        "test_guidance": "''",
        "topic": "org.centos.prod.ci.pipeline.image.test.smoke.complete",
        "type ": "qcow2",
        "username": "fedora-atomic"
      }
    }


class TestImageTestSmokeRunning(Base):
    """ These messages are published when the Atomic CI pipeline announces that
    the image generated from the compose containing a specified
    package has completed its tests.
    """

    expected_title = "ci.pipeline.image.test.smoke.running"
    expected_subti = 'Commit fff28640 of package rpms/nspr is ' \
        'being tested in an image in the Atomic CI pipeline on branch f26'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/132/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/nspr/'
         'fff28640d156c8b5e7302b7736e16442087b6007/'
         'f26/image/test/smoke/running'])
    msg = {
      "i": 1,
      "timestamp": 1500918319.0,
      "msg_id": "2017-b61a647a-8f98-4f2b-afe9-aa5a7f2ea257",
      "topic": "org.centos.prod.ci.pipeline.image.test.smoke.running",
      "source_version": "0.7.0",
      "msg": {
        "CI_NAME": "ci-pipeline-f26",
        "CI_TYPE": "custom",
        "branch": "f26",
        "build_id": "132",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/132/",
        "compose_rev": "b1777ffee14021a94d0b027fbcd841a15bd7cdeebd97527b742eab4e666dc9ec",
        "compose_url": "http://artifacts.ci.centos.org/artifacts/fedora-atomic/f26/ostree",
        "image_name": "fedora-atomic-26.223-b1777ffee14021a.qcow2",
        "image_url": "http://artifacts.ci.centos.org/artifacts/fedora-atomic/f26/images/fedora-atomic-26.223-b1777ffee14021a.qcow2",
        "message-content": "",
        "namespace": "rpms",
        "ref": "fedora/f26/x86_64/atomic-host",
        "repo": "nspr",
        "rev": "fff28640d156c8b5e7302b7736e16442087b6007",
        "status": "SUCCESS",
        "test_guidance": "''",
        "topic": "org.centos.prod.ci.pipeline.image.test.smoke.running",
        "type": "qcow2",
        "username": "fedora-atomic"
      }
    }


# The coming three tests are based on the documented expected format not
# on real messages, fingers crossed
# https://github.com/CentOS-PaaS-SIG/ci-pipeline/#orgcentosprodcipipelinepackagetestfunctionalqueued

class TestPackageTestFunctionalQueued(Base):
    """ These messages are published when the Atomic CI pipeline announces queuing
    the function tests of a package.
    """

    expected_title = "ci.pipeline.package.test.functional.queued"
    expected_subti = 'Commit 591b0d2f of package rpms/vim is queued for '\
        'functional testing in the Atomic CI pipeline on branch f26'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/91/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/vim/'
         '591b0d2fc67a45e4ad13bdc3e312d5554852426a/'
         'f26/package/test/functional/queued'])
    msg = {
      "i": 1,
      "timestamp": 1501741048,
      "msg_id": "2017-b420134c-0e39-4f70-8e5f-0975d7019e4b",
      "crypto": "x509",
      "topic": "org.centos.prod.ci.pipeline.package.test.functional.queued",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "91",
        "username": "fedora-atomic",
        "rev": "591b0d2fc67a45e4ad13bdc3e312d5554852426a",
        "message-content": "",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/91/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-f26",
        "repo": "vim",
        "topic": "org.centos.prod.ci.pipeline.package.test.functional.queued",
        "status": "SUCCESS",
        "test_guidance": "''",
        "branch": "f26",
        "package_url": "http://artifacts.ci.centos.org/fedora-atomic/f26/repo/vim_repo/",
        "ref": "fedora/f26/x86_64/atomic-host"
      }
    }


class TestPackageTestFunctionalRunning(Base):
    """ These messages are published when the Atomic CI pipeline announces running
    the function tests of a package.
    """

    expected_title = "ci.pipeline.package.test.functional.running"
    expected_subti = 'Commit 591b0d2f of package rpms/vim is running its '\
        'functional tests in the Atomic CI pipeline on branch f26'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/91/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/vim/'
         '591b0d2fc67a45e4ad13bdc3e312d5554852426a/'
         'f26/package/test/functional/running'])
    msg = {
      "i": 1,
      "timestamp": 1501741048,
      "msg_id": "2017-b420134c-0e39-4f70-8e5f-0975d7019e4b",
      "crypto": "x509",
      "topic": "org.centos.prod.ci.pipeline.package.test.functional.running",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "91",
        "username": "fedora-atomic",
        "rev": "591b0d2fc67a45e4ad13bdc3e312d5554852426a",
        "message-content": "",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/91/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-f26",
        "repo": "vim",
        "topic": "org.centos.prod.ci.pipeline.package.test.functional.queued",
        "status": "SUCCESS",
        "test_guidance": "''",
        "branch": "f26",
        "package_url": "http://artifacts.ci.centos.org/fedora-atomic/f26/repo/vim_repo/",
        "ref": "fedora/f26/x86_64/atomic-host"
      }
    }


class TestPackageTestFunctionalComplete(Base):
    """ These messages are published when the Atomic CI pipeline announces having
    completed the function tests of a package.
    """

    expected_title = "ci.pipeline.package.test.functional.complete"
    expected_subti = 'Commit 591b0d2f of package rpms/vim passed its '\
        'functional tests in the Atomic CI pipeline on branch f26'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/91/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/vim/'
         '591b0d2fc67a45e4ad13bdc3e312d5554852426a/'
         'f26/package/test/functional/complete'])
    msg = {
      "i": 1,
      "timestamp": 1501741048,
      "msg_id": "2017-b420134c-0e39-4f70-8e5f-0975d7019e4b",
      "crypto": "x509",
      "topic": "org.centos.prod.ci.pipeline.package.test.functional.complete",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "91",
        "username": "fedora-atomic",
        "rev": "591b0d2fc67a45e4ad13bdc3e312d5554852426a",
        "message-content": "",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/91/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-f26",
        "repo": "vim",
        "topic": "org.centos.prod.ci.pipeline.package.test.functional.queued",
        "status": "SUCCESS",
        "test_guidance": "''",
        "branch": "f26",
        "package_url": "http://artifacts.ci.centos.org/fedora-atomic/f26/repo/vim_repo/",
        "ref": "fedora/f26/x86_64/atomic-host"
      }
    }


class TestCompleteSuccess(Base):
    """ These messages are published when the Atomic CI pipeline announces having
    completed successfully running the entire pipeline on a package.
    """

    expected_title = "ci.pipeline.complete"
    expected_subti = 'Commit "591b0d2f" of package rpms/vim passed the Atomic CI pipeline on branch f26'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/91/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/vim/'
         '591b0d2fc67a45e4ad13bdc3e312d5554852426a/'
         'f26/complete'])
    msg = {
      "i": 1,
      "timestamp": 1501741048,
      "msg_id": "2017-b420134c-0e39-4f70-8e5f-0975d7019e4b",
      "crypto": "x509",
      "topic": "org.centos.prod.ci.pipeline.complete",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "91",
        "username": "fedora-atomic",
        "rev": "591b0d2fc67a45e4ad13bdc3e312d5554852426a",
        "message-content": "",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/91/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-f26",
        "repo": "vim",
        "topic": "org.centos.prod.ci.pipeline.complete",
        "status": "SUCCESS",
        "test_guidance": "''",
        "branch": "f26",
        "package_url": "http://artifacts.ci.centos.org/fedora-atomic/f26/repo/vim_repo/",
        "ref": "fedora/f26/x86_64/atomic-host"
      }
    }


class TestCompleteAborted(Base):
    """ These messages are published when the Atomic CI pipeline announces having
    aborted a run of the pipeline on a package.
    """

    expected_title = "ci.pipeline.complete"
    expected_subti = 'Commit "591b0d2f" of package rpms/vim was aborted on the Atomic CI pipeline on branch f26'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/91/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/vim/'
         '591b0d2fc67a45e4ad13bdc3e312d5554852426a/'
         'f26/complete'])
    msg = {
      "i": 1,
      "timestamp": 1501741048,
      "msg_id": "2017-b420134c-0e39-4f70-8e5f-0975d7019e4b",
      "crypto": "x509",
      "topic": "org.centos.prod.ci.pipeline.complete",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "91",
        "username": "fedora-atomic",
        "rev": "591b0d2fc67a45e4ad13bdc3e312d5554852426a",
        "message-content": "",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/91/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-f26",
        "repo": "vim",
        "topic": "org.centos.prod.ci.pipeline.complete",
        "status": "ABORTED",
        "test_guidance": "''",
        "branch": "f26",
        "package_url": "http://artifacts.ci.centos.org/fedora-atomic/f26/repo/vim_repo/",
        "ref": "fedora/f26/x86_64/atomic-host"
      }
    }


class TestCompleteFailed(Base):
    """ These messages are published when the Atomic CI pipeline announces having
    failed a run of the pipeline on a package.

    This means the pipeline failed to run the tests (as opposed to run the
    tests but these failed).
    """

    expected_title = "ci.pipeline.complete"
    expected_subti = 'Commit "591b0d2f" of package rpms/vim failed the Atomic CI pipeline on branch f26'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/91/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/vim/'
         '591b0d2fc67a45e4ad13bdc3e312d5554852426a/'
         'f26/complete'])
    msg = {
      "i": 1,
      "timestamp": 1501741048,
      "msg_id": "2017-b420134c-0e39-4f70-8e5f-0975d7019e4b",
      "crypto": "x509",
      "topic": "org.centos.prod.ci.pipeline.complete",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "91",
        "username": "fedora-atomic",
        "rev": "591b0d2fc67a45e4ad13bdc3e312d5554852426a",
        "message-content": "",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/91/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-f26",
        "repo": "vim",
        "topic": "org.centos.prod.ci.pipeline.complete",
        "status": "FAILEd",
        "test_guidance": "''",
        "branch": "f26",
        "package_url": "http://artifacts.ci.centos.org/fedora-atomic/f26/repo/vim_repo/",
        "ref": "fedora/f26/x86_64/atomic-host"
      }
    }


class TestCompleteError(Base):
    """ These messages are published when the Atomic CI pipeline announces having
    errored a run of the pipeline on a package.

    This means the pipeline could run the tests but the tests themselves failed
    (as opposed to the pipeline failed to run the tests).
    """

    expected_title = "ci.pipeline.complete"
    expected_subti = 'Commit "591b0d2f" of package rpms/vim errored the Atomic CI pipeline on branch f26'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/91/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '0a3d99117b8b56a071b50877c98db3dccbae292f188ef1a1c5b77f66d60c57fa'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['fedora-atomic'])
    expected_objects = set(
        ['rpms/vim/'
         '591b0d2fc67a45e4ad13bdc3e312d5554852426a/'
         'f26/complete'])
    msg = {
      "i": 1,
      "timestamp": 1501741048,
      "msg_id": "2017-b420134c-0e39-4f70-8e5f-0975d7019e4b",
      "crypto": "x509",
      "topic": "org.centos.prod.ci.pipeline.complete",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "91",
        "username": "fedora-atomic",
        "rev": "591b0d2fc67a45e4ad13bdc3e312d5554852426a",
        "message-content": "",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/job/ci-pipeline-f26/91/",
        "namespace": "rpms",
        "CI_NAME": "ci-pipeline-f26",
        "repo": "vim",
        "topic": "org.centos.prod.ci.pipeline.complete",
        "status": "UNSTABLE",
        "test_guidance": "''",
        "branch": "f26",
        "package_url": "http://artifacts.ci.centos.org/fedora-atomic/f26/repo/vim_repo/",
        "ref": "fedora/f26/x86_64/atomic-host"
      }
    }


class LegacyTestAllPackagesPackageRunning(Base):
    """ These messages are published when the Allpackages CI pipeline
    announces that the build of a package is running.
    """

    expected_title = "allpackages.pipeline.package.running"
    expected_subti = 'Commit 35cdcb6a of package rpms/gdb is '\
        'being built in the All Packages CI pipeline on branch f28'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/" \
        "blue/organizations/jenkins/upstream-fedora-f28-pipeline/detail/" \
        "upstream-fedora-f28-pipeline/335/pipeline/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '4a5e1bf0da6d9dfba3e0dc300fe58f6fc7d064df703eafbf2502dd900f69c1b4'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['jankratochvil'])
    expected_objects = set(
        ['rpms/gdb/35cdcb6a32562b632c075f2fd42793f7492dcdb3/'
         'f28/package/running'])
    msg = {
      "username": None,
      "source_name": "datanommer",
      "i": 1,
      "timestamp": 1522054091.0,
      "msg_id": "2018-cfb9a40e-3220-4dcf-a5aa-270a6cee975c",
      "crypto": "x509",
      "topic": "org.centos.prod.allpackages.pipeline.package.running",
      "headers": {},
      "source_version": "0.8.2",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "335",
        "original_spec_nvr": "",
        "username": "jankratochvil",
        "nvr": "",
        "rev": "35cdcb6a32562b632c075f2fd42793f7492dcdb3",
        "message-content": "",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/blue/organizations/jenkins/upstream-fedora-f28-pipeline/detail/upstream-fedora-f28-pipeline/335/pipeline/",
        "namespace": "rpms",
        "CI_NAME": "upstream-fedora-f28-pipeline",
        "repo": "gdb",
        "topic": "org.centos.prod.allpackages.pipeline.package.running",
        "status": "SUCCESS",
        "branch": "f28",
        "test_guidance": "''",
        "ref": "x86_64"
      }
    }


class LegacyTestAllPackagesCompleteSuccess(Base):
    """ These messages are published when the All Packages CI pipeline
    announces having completed successfully running the entire pipeline
    on a package.
    """

    expected_title = "allpackages.pipeline.complete"
    expected_subti = 'Commit "35cdcb6a" of package rpms/gdb passed the ' \
        'All Packages CI pipeline on branch f28'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/" \
        "blue/organizations/jenkins/upstream-fedora-f28-pipeline/detail/" \
        "upstream-fedora-f28-pipeline/335/pipeline/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '4a5e1bf0da6d9dfba3e0dc300fe58f6fc7d064df703eafbf2502dd900f69c1b4'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['jankratochvil'])
    expected_objects = set(
        ['rpms/gdb/'
         '35cdcb6a32562b632c075f2fd42793f7492dcdb3/'
         'f28/complete'])
    msg = {
      "username": None,
      "source_name": "datanommer",
      "i": 1,
      "timestamp": 1522055492.0,
      "msg_id": "2018-1436f172-aa90-49f2-9ff0-9b34608f38e8",
      "crypto": "x509",
      "topic": "org.centos.prod.allpackages.pipeline.complete",
      "headers": {},
      "source_version": "0.8.2",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "335",
        "original_spec_nvr": "",
        "username": "jankratochvil",
        "nvr": "",
        "rev": "35cdcb6a32562b632c075f2fd42793f7492dcdb3",
        "message-content": "",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/blue/organizations/jenkins/upstream-fedora-f28-pipeline/detail/upstream-fedora-f28-pipeline/335/pipeline/",
        "namespace": "rpms",
        "CI_NAME": "upstream-fedora-f28-pipeline",
        "repo": "gdb",
        "topic": "org.centos.prod.allpackages.pipeline.complete",
        "status": "SUCCESS",
        "branch": "f28",
        "test_guidance": "''",
        "ref": "x86_64"
      }
    }


class TestAllPackagesPackageRunning(Base):
    """ These messages are published when the Allpackages CI pipeline
    announces that the build of a package is running.
    """

    expected_title = "ci.pipeline.allpackages.package.running"
    expected_subti = 'Commit 35cdcb6a of package rpms/gdb is '\
        'being built in the All Packages CI pipeline on branch f28'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/" \
        "blue/organizations/jenkins/upstream-fedora-f28-pipeline/detail/" \
        "upstream-fedora-f28-pipeline/335/pipeline/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '4a5e1bf0da6d9dfba3e0dc300fe58f6fc7d064df703eafbf2502dd900f69c1b4'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['jankratochvil'])
    expected_objects = set(
        ['rpms/gdb/35cdcb6a32562b632c075f2fd42793f7492dcdb3/'
         'f28/allpackages/package/running'])
    msg = {
      "username": None,
      "source_name": "datanommer",
      "i": 1,
      "timestamp": 1522054091.0,
      "msg_id": "2018-cfb9a40e-3220-4dcf-a5aa-270a6cee975c",
      "crypto": "x509",
      "topic": "org.centos.prod.ci.pipeline.allpackages.package.running",
      "headers": {},
      "source_version": "0.8.2",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "335",
        "original_spec_nvr": "",
        "username": "jankratochvil",
        "nvr": "",
        "rev": "35cdcb6a32562b632c075f2fd42793f7492dcdb3",
        "message-content": "",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/blue/organizations/jenkins/upstream-fedora-f28-pipeline/detail/upstream-fedora-f28-pipeline/335/pipeline/",
        "namespace": "rpms",
        "CI_NAME": "upstream-fedora-f28-pipeline",
        "repo": "gdb",
        "topic": "org.centos.prod.ci.pipeline.allpackages.package.running",
        "status": "SUCCESS",
        "branch": "f28",
        "test_guidance": "''",
        "ref": "x86_64"
      }
    }


class TestAllPackagesCompleteSuccess(Base):
    """ These messages are published when the All Packages CI pipeline
    announces having completed successfully running the entire pipeline
    on a package.
    """

    expected_title = "ci.pipeline.allpackages.complete"
    expected_subti = 'Commit "35cdcb6a" of package rpms/gdb passed the ' \
        'All Packages CI pipeline on branch f28'
    expected_link = "https://jenkins-continuous-infra.apps.ci.centos.org/" \
        "blue/organizations/jenkins/upstream-fedora-f28-pipeline/detail/" \
        "upstream-fedora-f28-pipeline/335/pipeline/"
    expected_icon = "https://ci.centos.org/static/ec6de755/images/" \
        "headshot.png"
    expected_secondary_icon = 'https://seccdn.libravatar.org/avatar/'\
        '4a5e1bf0da6d9dfba3e0dc300fe58f6fc7d064df703eafbf2502dd900f69c1b4'\
        '?s=64&d=retro'
    expected_packages = set([])
    expected_usernames = set(['jankratochvil'])
    expected_objects = set(
        ['rpms/gdb/'
         '35cdcb6a32562b632c075f2fd42793f7492dcdb3/'
         'f28/allpackages/complete'])
    msg = {
      "username": None,
      "source_name": "datanommer",
      "i": 1,
      "timestamp": 1522055492.0,
      "msg_id": "2018-1436f172-aa90-49f2-9ff0-9b34608f38e8",
      "crypto": "x509",
      "topic": "org.centos.prod.ci.pipeline.allpackages.complete",
      "headers": {},
      "source_version": "0.8.2",
      "msg": {
        "CI_TYPE": "custom",
        "build_id": "335",
        "original_spec_nvr": "",
        "username": "jankratochvil",
        "nvr": "",
        "rev": "35cdcb6a32562b632c075f2fd42793f7492dcdb3",
        "message-content": "",
        "build_url": "https://jenkins-continuous-infra.apps.ci.centos.org/blue/organizations/jenkins/upstream-fedora-f28-pipeline/detail/upstream-fedora-f28-pipeline/335/pipeline/",
        "namespace": "rpms",
        "CI_NAME": "upstream-fedora-f28-pipeline",
        "repo": "gdb",
        "topic": "org.centos.prod.ci.pipeline.allpackages.complete",
        "status": "SUCCESS",
        "branch": "f28",
        "test_guidance": "''",
        "ref": "x86_64"
      }
    }


add_doc(locals())


if __name__ == '__main__':
    unittest.main()



import fedmsg.tests.test_meta

import arrow


class TestTaggerConglomerateByUser(
        fedmsg.tests.test_meta.ConglomerateBase):
    expected =[
        {'categories': set(['fedoratagger']),
         'end_time': 1436284694.0,
         'human_time': arrow.get(1436284677.6666667).humanize(),
         'icon': 'https://apps.fedoraproject.org/img/icons/tagger.png',
         'link': 'http://infrastructure.fedoraproject.org/infra/ansible.git/',
         'packages': set(['php-pear-console-color2']),
         'secondary_icon': 'https://seccdn.libravatar.org/avatar/'
         '1240f5f278e39089bdcee4c09aa4f6f8dc6e02b5446f61cb8c8c0bf9d53950a8'
         '?s=64&d=retro',
         'start_time': 1436284655.0,
         'subtitle': 'nalin voted on the tags: library '
         'and module to the packages: php-pear-console-color2',
         'subjective': 'nalin voted on the tags: library '
         'and module to the packages: php-pear-console-color2',
         'timestamp': 1436284677.6666667,
         'topics': set(['org.fedoraproject.prod.fedoratagger.tag.update']),
         'usernames': set(['nalin'])},
        {'categories': set(['fedoratagger']),
         'end_time': 1436270087.0,
         'human_time': arrow.get(1436269900.93).humanize(),
         'icon': 'https://apps.fedoraproject.org/img/icons/tagger.png',
         'link': 'http://infrastructure.fedoraproject.org/infra/ansible.git/',
         'packages': set(['GtkAda3',
                          'fedmsg',
                          'github2fedmsg',
                          'libgcrypt',
                          'modem-manager-gui',
                          'pam_krb5',
                          'ppp']),
         'secondary_icon': 'https://seccdn.libravatar.org/avatar/'
         '861506b8dba9fe9ee12a83ce2cd7c6fff15091298f9f1a4e6149876490c53e9b'
         '?s=64&d=retro',
         'start_time': 1436269755.0,
         'subtitle': 'pbrobinson voted on the tags: ada, crypto, '
         'and 13 others to the packages: GtkAda3, fedmsg, and 5 others',
         'subjective': 'pbrobinson voted on the tags: ada, crypto, '
         'and 13 others to the packages: GtkAda3, fedmsg, and 5 others',
         'timestamp': 1436269900.9333334,
         'topics': set(['org.fedoraproject.prod.fedoratagger.tag.update']),
         'usernames': set(['pbrobinson'])},
        {'categories': set(['fedoratagger']),
         'end_time': 1436269913.0,
         'human_time': arrow.get(1436269860.75).humanize(),
         'icon': 'https://apps.fedoraproject.org/img/icons/tagger.png',
         'link': 'http://infrastructure.fedoraproject.org/infra/ansible.git/',
         'packages': set(['fedmsg', 'pam_krb5', 'rstp']),
         'secondary_icon': 'https://seccdn.libravatar.org/avatar/'
         '861506b8dba9fe9ee12a83ce2cd7c6fff15091298f9f1a4e6149876490c53e9b'
         '?s=64&d=retro',
         'start_time': 1436269765.0,
         'subtitle': 'pbrobinson created new tags: authentication, msgbus, '
         'and 2 others on the packages: fedmsg, pam_krb5, and rstp',
         'subjective': 'pbrobinson created new tags: authentication, msgbus, '
         'and 2 others on the packages: fedmsg, pam_krb5, and rstp',
         'timestamp': 1436269860.75,
         'topics': set(['org.fedoraproject.prod.fedoratagger.tag.create']),
         'usernames': set(['pbrobinson'])}
    ]
    originals = [{
        "i": 15,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 2,
                "package": "php-pear-console-color2",
                "tag": "module",
                "total": 2,
                "votes": 2
            },
            "user": {
                "anonymous": False,
                "rank": 231,
                "score": 2,
                "username": "nalin",
                "votes": 2
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 2,
                    "package": "php-pear-console-color2",
                    "tag": "module",
                    "total": 2,
                    "votes": 2
                },
                "user": {
                    "anonymous": False,
                    "rank": 231,
                    "score": 2,
                    "username": "nalin",
                    "votes": 2
                }
            }
        },
        "msg_id": "2015-ad796f57-d993-4b01-be34-97d24a144f83",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436284694.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 15,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 2,
                "package": "php-pear-console-color2",
                "tag": "library",
                "total": 2,
                "votes": 2
            },
            "user": {
                "anonymous": False,
                "rank": 231,
                "score": 2,
                "username": "nalin",
                "votes": 2
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 2,
                    "package": "php-pear-console-color2",
                    "tag": "library",
                    "total": 2,
                    "votes": 2
                },
                "user": {
                    "anonymous": False,
                    "rank": 231,
                    "score": 2,
                    "username": "nalin",
                    "votes": 2
                }
            }
        },
        "msg_id": "2015-1d1206f8-60ed-4e4c-b5b4-09c55231bafc",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436284692.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 14,
        "msg": {
            "tag": {
                "dislike": 1,
                "like": 1,
                "package": "php-pear-console-color2",
                "tag": "library",
                "total": 0,
                "votes": 2
            },
            "user": {
                "anonymous": False,
                "rank": 231,
                "score": 2,
                "username": "nalin",
                "votes": 2
            },
            "vote": {
                "like": False,
                "tag": {
                    "dislike": 1,
                    "like": 1,
                    "package": "php-pear-console-color2",
                    "tag": "library",
                    "total": 0,
                    "votes": 2
                },
                "user": {
                    "anonymous": False,
                    "rank": 231,
                    "score": 2,
                    "username": "nalin",
                    "votes": 2
                }
            }
        },
        "msg_id": "2015-a46f0f83-2f7f-4aeb-a662-1f5982a1db85",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436284687.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 13,
        "msg": {
            "tag": {
                "dislike": 1,
                "like": 1,
                "package": "php-pear-console-color2",
                "tag": "module",
                "total": 0,
                "votes": 2
            },
            "user": {
                "anonymous": False,
                "rank": 231,
                "score": 2,
                "username": "nalin",
                "votes": 2
            },
            "vote": {
                "like": False,
                "tag": {
                    "dislike": 1,
                    "like": 1,
                    "package": "php-pear-console-color2",
                    "tag": "module",
                    "total": 0,
                    "votes": 2
                },
                "user": {
                    "anonymous": False,
                    "rank": 231,
                    "score": 2,
                    "username": "nalin",
                    "votes": 2
                }
            }
        },
        "msg_id": "2015-9d2de038-01c7-440a-9f2a-4f7518919366",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436284683.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 15,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 2,
                "package": "php-pear-console-color2",
                "tag": "module",
                "total": 2,
                "votes": 2
            },
            "user": {
                "anonymous": False,
                "rank": 231,
                "score": 0.5,
                "username": "nalin",
                "votes": 1
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 2,
                    "package": "php-pear-console-color2",
                    "tag": "module",
                    "total": 2,
                    "votes": 2
                },
                "user": {
                    "anonymous": False,
                    "rank": 231,
                    "score": 0.5,
                    "username": "nalin",
                    "votes": 1
                }
            }
        },
        "msg_id": "2015-60108dbb-ab48-42ef-8c80-e4443cce56f8",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436284655.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 12,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 2,
                "package": "php-pear-console-color2",
                "tag": "library",
                "total": 2,
                "votes": 2
            },
            "user": {
                "anonymous": False,
                "rank": 231,
                "score": 1.5,
                "username": "nalin",
                "votes": 2
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 2,
                    "package": "php-pear-console-color2",
                    "tag": "library",
                    "total": 2,
                    "votes": 2
                },
                "user": {
                    "anonymous": False,
                    "rank": 231,
                    "score": 1.5,
                    "username": "nalin",
                    "votes": 2
                }
            }
        },
        "msg_id": "2015-6c58888b-ab74-4c53-bb14-53d2ff42bfaa",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436284655.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 10,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 3,
                "package": "modem-manager-gui",
                "tag": "modem",
                "total": 3,
                "votes": 3
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 190.5,
                "username": "pbrobinson",
                "votes": 126
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 3,
                    "package": "modem-manager-gui",
                    "tag": "modem",
                    "total": 3,
                    "votes": 3
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 190.5,
                    "username": "pbrobinson",
                    "votes": 126
                }
            }
        },
        "msg_id": "2015-1ee9888a-4f00-4eb5-8ebd-d31e89b3f7f2",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436270087.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 11,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 5,
                "package": "github2fedmsg",
                "tag": "fedmsg",
                "total": 5,
                "votes": 5
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 189.5,
                "username": "pbrobinson",
                "votes": 125
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 5,
                    "package": "github2fedmsg",
                    "tag": "fedmsg",
                    "total": 5,
                    "votes": 5
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 189.5,
                    "username": "pbrobinson",
                    "votes": 125
                }
            }
        },
        "msg_id": "2015-f3923e94-d145-4254-8582-a8e69799d4b7",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436270056.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 14,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 5,
                "package": "github2fedmsg",
                "tag": "github",
                "total": 5,
                "votes": 5
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 188.5,
                "username": "pbrobinson",
                "votes": 124
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 5,
                    "package": "github2fedmsg",
                    "tag": "github",
                    "total": 5,
                    "votes": 5
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 188.5,
                    "username": "pbrobinson",
                    "votes": 124
                }
            }
        },
        "msg_id": "2015-f30906f2-e0fd-45d9-bb6e-0d3fa2a7e3ed",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436270054.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 13,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 3,
                "package": "ppp",
                "tag": "network",
                "total": 3,
                "votes": 3
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 187.5,
                "username": "pbrobinson",
                "votes": 123
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 3,
                    "package": "ppp",
                    "tag": "network",
                    "total": 3,
                    "votes": 3
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 187.5,
                    "username": "pbrobinson",
                    "votes": 123
                }
            }
        },
        "msg_id": "2015-7d8eb8ed-c13d-4b7f-b009-4595c98b3115",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436269987.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 10,
        "msg": {
            "tag": {
                "dislike": 1,
                "like": 3,
                "package": "ppp",
                "tag": "ppp",
                "total": 2,
                "votes": 4
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 186.5,
                "username": "pbrobinson",
                "votes": 122
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 1,
                    "like": 3,
                    "package": "ppp",
                    "tag": "ppp",
                    "total": 2,
                    "votes": 4
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 186.5,
                    "username": "pbrobinson",
                    "votes": 122
                }
            }
        },
        "msg_id": "2015-d56c5828-e013-4d2f-a26f-57c7cdfd688b",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436269986.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 9,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 4,
                "package": "libgcrypt",
                "tag": "cryptography",
                "total": 4,
                "votes": 4
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 185.5,
                "username": "pbrobinson",
                "votes": 121
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 4,
                    "package": "libgcrypt",
                    "tag": "cryptography",
                    "total": 4,
                    "votes": 4
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 185.5,
                    "username": "pbrobinson",
                    "votes": 121
                }
            }
        },
        "msg_id": "2015-8cd2b9d5-5237-4895-b259-bdd51a69cd21",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436269931.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 9,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 5,
                "package": "libgcrypt",
                "tag": "crypto",
                "total": 5,
                "votes": 5
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 184.5,
                "username": "pbrobinson",
                "votes": 120
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 5,
                    "package": "libgcrypt",
                    "tag": "crypto",
                    "total": 5,
                    "votes": 5
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 184.5,
                    "username": "pbrobinson",
                    "votes": 120
                }
            }
        },
        "msg_id": "2015-9db798bc-4ae4-429e-9745-04cc7dd61b50",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436269928.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 8,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 1,
                "package": "rstp",
                "tag": "routing protocol",
                "total": 1,
                "votes": 1
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 184,
                "username": "pbrobinson",
                "votes": 119
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 1,
                    "package": "rstp",
                    "tag": "routing protocol",
                    "total": 1,
                    "votes": 1
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 184,
                    "username": "pbrobinson",
                    "votes": 119
                }
            }
        },
        "msg_id": "2015-2c67e7e4-6460-4da5-9316-ca5f259f244b",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436269913.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.create"
    },
    {
        "i": 4,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 1,
                "package": "rstp",
                "tag": "network",
                "total": 1,
                "votes": 1
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 182,
                "username": "pbrobinson",
                "votes": 118
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 1,
                    "package": "rstp",
                    "tag": "network",
                    "total": 1,
                    "votes": 1
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 182,
                    "username": "pbrobinson",
                    "votes": 118
                }
            }
        },
        "msg_id": "2015-5aeca8f3-9b52-4cbc-91c4-d565c2238bfd",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436269904.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.create"
    },
    {
        "i": 9,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 1,
                "package": "fedmsg",
                "tag": "msgbus",
                "total": 1,
                "votes": 1
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 180,
                "username": "pbrobinson",
                "votes": 117
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 1,
                    "package": "fedmsg",
                    "tag": "msgbus",
                    "total": 1,
                    "votes": 1
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 180,
                    "username": "pbrobinson",
                    "votes": 117
                }
            }
        },
        "msg_id": "2015-0c2bd9e4-15f2-4980-9ce5-6fb749859770",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436269861.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.create"
    },
    {
        "i": 9,
        "msg": {
            "tag": {
                "dislike": 1,
                "like": 6,
                "package": "fedmsg",
                "tag": "open infrastructure",
                "total": 5,
                "votes": 7
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 177.5,
                "username": "pbrobinson",
                "votes": 116
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 1,
                    "like": 6,
                    "package": "fedmsg",
                    "tag": "open infrastructure",
                    "total": 5,
                    "votes": 7
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 177.5,
                    "username": "pbrobinson",
                    "votes": 116
                }
            }
        },
        "msg_id": "2015-ddd21ea6-2906-4308-8dea-a8fd10df3ed3",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436269847.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 8,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 6,
                "package": "fedmsg",
                "tag": "zeromq",
                "total": 6,
                "votes": 6
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 175.5,
                "username": "pbrobinson",
                "votes": 114
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 6,
                    "package": "fedmsg",
                    "tag": "zeromq",
                    "total": 6,
                    "votes": 6
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 175.5,
                    "username": "pbrobinson",
                    "votes": 114
                }
            }
        },
        "msg_id": "2015-6d3fd8d8-e21f-4dd9-8b05-295231dbbe25",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436269845.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 8,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 5,
                "package": "fedmsg",
                "tag": "fedora",
                "total": 5,
                "votes": 5
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 176.5,
                "username": "pbrobinson",
                "votes": 115
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 5,
                    "package": "fedmsg",
                    "tag": "fedora",
                    "total": 5,
                    "votes": 5
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 176.5,
                    "username": "pbrobinson",
                    "votes": 115
                }
            }
        },
        "msg_id": "2015-9fc045bf-c593-484d-bb32-d0a2538721de",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436269845.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 7,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 7,
                "package": "GtkAda3",
                "tag": "gtk",
                "total": 7,
                "votes": 7
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 174.5,
                "username": "pbrobinson",
                "votes": 113
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 7,
                    "package": "GtkAda3",
                    "tag": "gtk",
                    "total": 7,
                    "votes": 7
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 174.5,
                    "username": "pbrobinson",
                    "votes": 113
                }
            }
        },
        "msg_id": "2015-34f75959-3994-4bc9-bd73-8036d02f6efe",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436269840.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 10,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 6,
                "package": "GtkAda3",
                "tag": "ada",
                "total": 6,
                "votes": 6
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 173.5,
                "username": "pbrobinson",
                "votes": 112
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 6,
                    "package": "GtkAda3",
                    "tag": "ada",
                    "total": 6,
                    "votes": 6
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 173.5,
                    "username": "pbrobinson",
                    "votes": 112
                }
            }
        },
        "msg_id": "2015-3b902a67-01cf-45ae-b6d6-9080217c5b28",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436269837.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 7,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 4,
                "package": "pam_krb5",
                "tag": "authentication",
                "total": 4,
                "votes": 4
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 173,
                "username": "pbrobinson",
                "votes": 111
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 4,
                    "package": "pam_krb5",
                    "tag": "authentication",
                    "total": 4,
                    "votes": 4
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 173,
                    "username": "pbrobinson",
                    "votes": 111
                }
            }
        },
        "msg_id": "2015-3d543935-bd79-4c06-b84e-b58ff0e0e351",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436269765.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.create"
    },
    {
        "i": 6,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 4,
                "package": "pam_krb5",
                "tag": "krb5",
                "total": 4,
                "votes": 4
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 171.5,
                "username": "pbrobinson",
                "votes": 110
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 4,
                    "package": "pam_krb5",
                    "tag": "krb5",
                    "total": 4,
                    "votes": 4
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 171.5,
                    "username": "pbrobinson",
                    "votes": 110
                }
            }
        },
        "msg_id": "2015-69169809-4307-44aa-a76b-9a32e11de4a6",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436269759.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 12,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 7,
                "package": "pam_krb5",
                "tag": "kerberos",
                "total": 7,
                "votes": 7
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 170.5,
                "username": "pbrobinson",
                "votes": 109
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 7,
                    "package": "pam_krb5",
                    "tag": "kerberos",
                    "total": 7,
                    "votes": 7
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 170.5,
                    "username": "pbrobinson",
                    "votes": 109
                }
            }
        },
        "msg_id": "2015-a4ccaf4f-8ed6-4ba4-be74-02d868de1e8a",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436269757.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    },
    {
        "i": 5,
        "msg": {
            "tag": {
                "dislike": 0,
                "like": 7,
                "package": "pam_krb5",
                "tag": "pam",
                "total": 7,
                "votes": 7
            },
            "user": {
                "anonymous": False,
                "rank": 139,
                "score": 169.5,
                "username": "pbrobinson",
                "votes": 108
            },
            "vote": {
                "like": True,
                "tag": {
                    "dislike": 0,
                    "like": 7,
                    "package": "pam_krb5",
                    "tag": "pam",
                    "total": 7,
                    "votes": 7
                },
                "user": {
                    "anonymous": False,
                    "rank": 139,
                    "score": 169.5,
                    "username": "pbrobinson",
                    "votes": 108
                }
            }
        },
        "msg_id": "2015-96e05d2c-a4f4-4b07-92f7-bb6be7f3bb02",
        "source_name": "datanommer",
        "source_version": "0.6.5",
        "timestamp": 1436269755.0,
        "topic": "org.fedoraproject.prod.fedoratagger.tag.update"
    }]



# This file is part of fedmsg.
# Copyright (C) 2013, 2014 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#

from fedmsg_meta_fedora_infrastructure import BaseProcessor


class MirrorManagerProcessor(BaseProcessor):
    __name__ = "mirrormanager"
    __description__ = "Mirror Manager activity"
    __link__ = "https://mirrors.fedoraproject.org"
    __docs__ = "https://github.com/fedora-infra/mirrormanager2"
    __obj__ = "Mirror Updates"
    __icon__ = "https://apps.fedoraproject.org/img/icons/downloads.png"

    def link(self, msg, **config):
        return self.__link__

    def subtitle(self, msg, **config):
        topic, msg = msg['topic'], msg['msg']
        if 'mirrormanager.crawler.complete' in topic:
            results = msg['results']
            total = len(results)
            succeeded = len([1 for r in results if r['rc'] == 0])
            failed = len([1 for r in results if r['rc'] != 0])
            tmpl = self._(
                "mirrormanager's crawler finished a crawl of {total} mirrors "
                "({succeeded} succeeded, {failed} failed)"
            )
            return tmpl.format(total=total, succeeded=succeeded, failed=failed)
        elif 'mirrormanager.crawler.start' in topic:
            total = len(msg['hosts'])
            tmpl = self._(
                "mirrormanager's crawler started a crawl of {total} mirrors")
            return tmpl.format(total=total)
        elif 'mirrormanager.netblocks.get' in topic:
            type = msg['type']

            if msg['success']:
                status = self._("successfully updated")
            else:
                status = self._("failed to update")

            tmpl = self._(
                "mirrormanager's backend {status} its {type} netblocks file")
            return tmpl.format(status=status, type=type)

    def secondary_icon(self, msg, **config):
        return self.icon(msg, **config)

    def usernames(self, msg, **config):
        return set()

    def packages(self, msg, **config):
        return set()

    def objects(self, msg, **config):
        if 'mirrormanager.crawler' in msg['topic']:
            if 'hosts' in msg['msg']:
                return set([
                    'mirrors/%s' % host.get('host', host.get('name'))
                    for host in msg['msg']['hosts']
                ])
            else:
                return set([
                    'mirrors/%s' % result['host']['name']
                    for result in msg['msg']['results']
                ])
        if 'mirrormanager.netblocks' in msg['topic']:
            return set([
                'netblocks/' + msg['msg']['type']
            ])

        return set([])




# This file is part of fedmsg.
# Copyright (C) 2017 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#

from fedmsg_meta_fedora_infrastructure.fasshim import avatar_url
from fedmsg_meta_fedora_infrastructure import BaseProcessor

class MBSProcessor(BaseProcessor):
    __name__ = "mbs"
    __description__ = "Module Build Service"
    __link__ = "https://mbs.fedoraproject.org"
    __docs__ = "https://fedoraproject.org/wiki/Changes/ModuleBuildService"
    __obj__ = "Module Builds"
    __icon__ = "https://apps.fedoraproject.org/img/icons/modularity.png"

    def link(self, msg, **config):
        tmpl = "https://mbs.fedoraproject.org/module-build-service/1/module-builds/{id}"
        return tmpl.format(**msg['msg'])

    def subtitle(self, msg, **config):
        tmpl = self._(
            "{owner}'s build of modules/{name} entered the {state_name} state."
        )
        return tmpl.format(**msg['msg'])

    def secondary_icon(self, msg, **config):
        user = msg['msg']['owner']
        return avatar_url(user)

    def usernames(self, msg, **config):
        user = msg['msg']['owner']
        return set([user])

    def objects(self, msg, **config):
        return set([msg['msg']['name']])

    def packages(self, msg, **config):
        return set([]) # Not sure what to do with this yet...



# This file is part of fedmsg.
# Copyright (C) 2012 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#
from fedmsg_meta_fedora_infrastructure import BaseProcessor


class ComposeProcessor(BaseProcessor):
    __name__ = "compose"
    __description__ = "Fedora Release Engineering"
    __link__ = "https://pagure.io/releng"
    __docs__ = "https://pagure.io/docs/releng"
    __obj__ = "Composes"

    # dicts mapping topic substrings to subtitle event texts
    # These are the old 'make-updates' topics
    makeupevents = {
        '.make-updates.':       "",
        '.cloudimg-build.':     " building images for",
        '.mash-atomic':         " Atomic updates mash for",
        '.atomic-lorax':        " Atomic lorax run for",
        '.cloudimg-checksum.':  " image checksum generation for",
        '.cloudimg-staging.':   " master mirror publication for",
    }
    # as these events only existed prior to pungi 4 and the creation
    # of different 'dists', we can always treat the shortname / dist
    # as 'Fedora' for these
    oldevents = {
        '.mash.':               " mashing",
        '.pungify.':            " building boot.iso for",
        '.image.':              " building other images for",
    }
    oldevents.update(makeupevents)
    # These ones existed after pungi 4, so we cannot make inferences
    # about the dist / shortname; bare 'start' and 'complete' are
    # implicitly in this set too
    events = {
        '.rsync.':              " master mirror publication for",
    }
    allevents = dict()
    allevents.update(oldevents)
    allevents.update(events)

    def subtitle(self, msg, **config):

        # decide what event we're dealing with
        gotevent = False
        for event in self.allevents:
            if event in msg['topic']:
                gotevent = True
                evtext = self.allevents[event]
                # allow definition of event to leak
                break
        if not gotevent:
            # assume this is an overall compose start/done event
            event = 'compose'
            evtext = ''

        # discover the release number, if we can
        release = "(unknown release)"
        try:
            # 'branch' key is usually the release identifier (number or
            # 'rawhide' or 'bikeshed'), but for a while for modular
            # composes it was 'Modular-(release)', so handle that
            release = msg['msg']['branch'].split('Modular-')[-1].capitalize()
        except KeyError:
            # Some old messages in datanommer don't have that branch field,
            # so we have to extract it from the topic.
            comps = msg['topic'].split('.')
            if 'rawhide' in comps:
                release = "Rawhide"
            elif 'epelbeta' in comps:
                release = "EPEL Beta"
            else:
                # I'm not sure this is ever actually the case - a message with
                # a release number in the topic, but no 'branch' key - but
                # just in case, let's handle it
                for comp in comps:
                    if len(comp) == 2 and comp.isdigit():
                        release = comp
                        break

        # for old secondary arches, discover the arch and pad it
        arch = msg['msg'].get('arch', '')
        arch = arch and ' (%s)' % arch

        # set up compose ID text, if we have one
        if event in self.makeupevents:
            comptext = "post-release Cloud/Atomic/Docker respin compose"
        else:
            comptext = "compose"
        cid = msg['msg'].get('compose_id', '')
        if cid:
            comptext += " %s" % cid

        # Try to figure out the 'shortname', if we can, which differentiates
        # various types of compose
        try:
            short = msg['msg']['short']
        except KeyError:
            # default value
            short = 'Fedora'
            # this identifies modular composes before we added 'short' key
            if 'modular' in msg['msg'].get('branch', '').lower():
                short = 'Fedora-Modular'
            # these are known ambiguous: these messages could be for a
            # branched compose (Fedora), or a post-release Fedora-Atomic,
            # Fedora-Cloud or Fedora-Docker respin. If the message has a
            # compose_id but not a short, it must be for Fedora (we fixed
            # inclusion of compose_id for the other shortnames at the
            # same time we added the short key). If the message has an
            # arch it must be for Fedora (separate secondary arch composes
            # went away with the Pungi 4 migration which added shortnames).
            # 'branched' messages must be for Fedora as we switched to
            # numeric topics with the Pungi 4 migration.
            if release.isdigit() and event not in self.oldevents:
                if 'compose_id' not in msg['msg'] and not arch and 'branched' not in msg['topic']:
                    short = 'Fedora, Fedora-Atomic, Fedora-Cloud or Fedora-Docker'

        # Set the 'action' text; note we do not use the 'log' value
        # here because it's sometimes a lie, e.g. mash-atomic.stop
        # messages have their 'log' value as 'start'
        action = 'Did something to do with'
        actsplit = msg['topic'].split('.')[-1]
        if actsplit == 'start':
            action = 'Started'
        elif actsplit in ('complete', 'done', 'stop'):
            action = 'Completed'

        # Finally, construct the message
        tmpl = "{action}{evtext} {short} {release}{arch} {comptext}"
        return tmpl.format(action=action, evtext=evtext, short=short, release=release,
                           arch=arch, comptext=comptext)

    def link(self, msg, **config):
        return msg['msg'].get('location', 'https://kojipkgs.fedoraproject.org/compose/')

    def objects(self, msg, **config):
        branch = msg['topic'].split('.')[4]
        arch = msg['msg'].get('arch', '')
        arch = arch or 'primary'
        return set(["%s/%s" % (branch, arch)])



# This file is part of fedmsg.
# Copyright (C) 2014 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Pierre-Yves Chibon <pingou@pingoured.fr>
#           Ralph Bean <rbean@redhat.com>
#
""" Tests for elections/voting messages """

import unittest

from fedmsg.tests.test_meta import Base

from .common import add_doc


class TestLegacyElectionsNew(Base):
    """ Old style... """

    expected_title = "fedora_elections.election.new"
    expected_subti = 'pingou created election "test"'
    expected_link = "https://admin.fedoraproject.org/voting/about/test"
    expected_icon = (None)
    expected_secondary_icon = (
        "https://seccdn.libravatar.org/avatar/"
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c"
        "?s=64&d=retro")
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['test/election/new'])
    msg = {
        "username": "pingou",
        "i": 1,
        "timestamp": 1379638157.759283,
        "msg_id": "2013-96f9ca0e-c7c6-43f0-9de7-7a268c7f1cef",
        "topic": "org.fedoraproject.dev.fedora_elections.election.new",
        "msg": {
            "election": {
                "description": "test desc",
                "end_date": 1397080800.0,
                "url": "http: //giuakle.org",
                "embargoed": 1,
                "alias": "test",
                "shortdesc": "test",
                "voting_type": "range",
                "start_date": 1396994400.0
            },
            "agent": "pingou"
        }
    }


class TestElectionsEdit(Base):
    """ These messages are published when someone edit an elections in
    `elections <https://admin.fedoraproject.org/voting/>`_.
    """

    expected_title = "fedora_elections.election.edit"
    expected_subti = 'pingou edited election "test"'
    expected_link = "https://admin.fedoraproject.org/voting/about/test"
    expected_icon = (None)
    expected_secondary_icon = (
        "https://seccdn.libravatar.org/avatar/"
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c"
        "?s=64&d=retro")
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['test/election/edit'])
    msg = {
        "username": "pingou",
        "i": 1,
        "timestamp": 1379638157.759283,
        "msg_id": "2013-96f9ca0e-c7c6-43f0-9de7-7a268c7f1cef",
        "topic": "org.fedoraproject.dev.fedora_elections.election.edit",
        "msg": {
            "election": {
                "description": "test desc",
                "end_date": 1397080800.0,
                "url": "http: //giuakle.org",
                "embargoed": 1,
                "alias": "test",
                "shortdesc": "test",
                "voting_type": "range",
                "start_date": 1396994400.0
            },
            "agent": "pingou"
        }
    }


class TestElectionsCandidateNew(Base):
    """ These messages are published when someone added a candidate to an
    elections in `elections <https://admin.fedoraproject.org/voting/>`_.
    """

    expected_title = "fedora_elections.candidate.new"
    expected_subti = 'pingou added candidate "Toshio" to election "test"'
    expected_link = "https://admin.fedoraproject.org/voting/about/test"
    expected_icon = (None)
    expected_secondary_icon = (
        "https://seccdn.libravatar.org/avatar/"
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c"
        "?s=64&d=retro")
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['test/candidate/new'])
    msg = {
        "username": "pingou",
        "i": 1,
        "timestamp": 1379638157.759283,
        "msg_id": "2013-96f9ca0e-c7c6-43f0-9de7-7a268c7f1cef",
        "topic": "org.fedoraproject.dev.fedora_elections.candidate.new",
        "msg": {
            "election": {
                "description": "test desc",
                "end_date": 1397080800.0,
                "url": "http: //giuakle.org",
                "embargoed": 1,
                "alias": "test",
                "shortdesc": "test",
                "voting_type": "range",
                "start_date": 1396994400.0
            },
            'candidate': {
                'url': '',
                'name': 'Toshio'
            },
            "agent": "pingou"
        }
    }


class TestElectionsCandidateEdit(Base):
    """ These messages are published when someone edited a candidate of an
    elections in `elections <https://admin.fedoraproject.org/voting/>`_.
    """

    expected_title = "fedora_elections.candidate.edit"
    expected_subti = 'pingou edited candidate "Toshio" of election "test"'
    expected_link = "https://admin.fedoraproject.org/voting/about/test"
    expected_icon = (None)
    expected_secondary_icon = (
        "https://seccdn.libravatar.org/avatar/"
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c"
        "?s=64&d=retro")
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['test/candidate/edit'])
    msg = {
        "username": "pingou",
        "i": 1,
        "timestamp": 1379638157.759283,
        "msg_id": "2013-96f9ca0e-c7c6-43f0-9de7-7a268c7f1cef",
        "topic": "org.fedoraproject.dev.fedora_elections.candidate.edit",
        "msg": {
            "election": {
                "description": "test desc",
                "end_date": 1397080800.0,
                "url": "http: //giuakle.org",
                "embargoed": 1,
                "alias": "test",
                "shortdesc": "test",
                "voting_type": "range",
                "start_date": 1396994400.0
            },
            'candidate': {
                'url': '',
                'name': 'Toshio'
            },
            "agent": "pingou"
        }
    }


class TestElectionsCandidateDelete(Base):
    """ These messages are published when someone add a candidate to an
    elections in `elections <https://admin.fedoraproject.org/voting/>`_.
    """

    expected_title = "fedora_elections.candidate.delete"
    expected_subti = 'pingou deleted candidate "Toshio" of election "test"'
    expected_link = "https://admin.fedoraproject.org/voting/about/test"
    expected_icon = (None)
    expected_secondary_icon = (
        "https://seccdn.libravatar.org/avatar/"
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c"
        "?s=64&d=retro")
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['test/candidate/delete'])
    msg = {
        "username": "pingou",
        "i": 1,
        "timestamp": 1379638157.759283,
        "msg_id": "2013-96f9ca0e-c7c6-43f0-9de7-7a268c7f1cef",
        "topic": "org.fedoraproject.dev.fedora_elections.candidate.delete",
        "msg": {
            "election": {
                "description": "test desc",
                "end_date": 1397080800.0,
                "url": "http: //giuakle.org",
                "embargoed": 1,
                "alias": "test",
                "shortdesc": "test",
                "voting_type": "range",
                "start_date": 1396994400.0
            },
            'candidate': {
                'url': '',
                'name': 'Toshio'
            },
            "agent": "pingou"
        }
    }


class TestElectionsNew(Base):
    """ These messages are published when someone creates a new elections
    in `elections <https://admin.fedoraproject.org/voting/>`_.
    """

    expected_title = "fedora_elections.election.new"
    expected_subti = 'jreznik created election "council-nov14"'
    expected_link = "https://admin.fedoraproject.org/voting/about/council-nov14"
    expected_icon = (None)
    expected_secondary_icon = (
        "https://seccdn.libravatar.org/avatar/"
        "6a345b20c10f890075dab7cc5ac70fdc93167bfd40a4f9299bc77f5a0238a5cc"
        "?s=64&d=retro")
    expected_packages = set([])
    expected_usernames = set(['jreznik'])
    expected_objects = set(['council-nov14/election/new'])
    msg = {
        "i": 2,
        "msg": {
            "admin_groups": [],
            "alias": "council-nov14",
            "candidates": [],
            "candidates_are_fasusers": 1,
            "description": "The Fedora Council is our top-level community ...",
            "embargoed": 1,
            "end_date": 1417046399.0,
            "fas_user": "jreznik",
            "id": 65,
            "legal_voters": [{
                "election": 65,
                "election_id": 65,
                "group_name": "anycla",
                "id": 67
            }],
            "max_votes": None,
            "seats_elected": 2,
            "shortdesc": "Council - November 2014",
            "start_date": 1416268800.0,
            "url": "http://fedoraproject.org/wiki/Council/Nominations",
            "votes": [],
            "voting_type": "range"
        },
        "msg_id": "2014-6a4e287c-a65f-488f-8ba7-5b454a50642c",
        "source_name": "datanommer",
        "source_version": "0.6.4",
        "timestamp": 1416208425.0,
        "topic": "org.fedoraproject.prod.fedora_elections.election.new",
    }


add_doc(locals())

if __name__ == '__main__':
    unittest.main()
